#!/bin/sh
#
# Licensed Materials - Property of IBM
# 5724-L62
#
# (C) Copyright IBM Corp. 2005  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# @(#)33   1.6   common/src/bin/amctl.sh, am_common, claret, 20050421163510 2/10/05 18:31:35
#
# (c) 2002-2004 Cyanea Systems Corp.
# All Rights Reserved
#

# Set environment variables.

if [ -z "$WSAMBIN" ]
then
        myDir=`dirname ${0}`
else
        myDir="$WSAMBIN"
fi

myName=`basename ${0}`

OS=`uname`
if [ "$OS" = "Windows" ]; then
	echo "This script can not run without a shell envirnment."
	echo "Aborting..."
	exit 50
elif [ "$OS" = "Interix" ]; then
	oldDir=`pwd`
	cd $myDir	
	. ./setenv.sh
else
	if [ -f ${myDir}/setenv.sh ]
	then
        	. ${myDir}/setenv.sh
	fi
fi

# Function to print out help on command usage.

usage()
{
	echo "${myName}: Usage: $myName <property file name> <command>"
	echo " Components:";
	echo "  kl1 - first instance of the kernel"
	echo "  kl2 - second instance of the kernel"
	echo "  dc  - data collector"
	echo "  ps1 - first instance of the publish server"
	echo "  ps2 - second instance of the publish server"
	echo "  aa1  - first instance of archive agent"
	echo "  aa2  - second instance of archive agent"
	echo "  md - message dispatcher"
	echo "  sam1 - first instance of SAM GPS"
      echo "  pa  - polling agent"
	echo " Possible commands:";  
	echo "  start      - start component";
	echo "  stop       - stop component";
	echo "  ping       - ping component";
	echo "  status     - retrieve component status";
	echo "  debug      - switch to debugging mode";
	echo "  info       - switch to informative mode";
	echo "  warn       - switch to warning mode";
	exit 1
}

# Process command line arguments.

PROP_FILE_NAME=$1
COMMAND=$2
SUBSYSTEM=`echo ${PROP_FILE_NAME} | cut -c1-2`

if [ "${PROP_FILE_NAME}" = "wd1" ] ; then
   PROP_FILE_NAME=kl1
elif [ "${PROP_FILE_NAME}" = "wd2" ] ; then
   PROP_FILE_NAME=kl2
fi

case $SUBSYSTEM in
 	wd )
                EXEC_COMMAND=${CYANEA_HOME}/bin/wdbgctl.sh
        ;;
	kl )
		EXEC_COMMAND=${CYANEA_HOME}/bin/klctl.sh
	;;
	ps )
		EXEC_COMMAND=${CYANEA_HOME}/bin/psctl.sh
	;;
	aa )
		EXEC_COMMAND=${CYANEA_HOME}/bin/aactl.sh
	;;
        pa )
		EXEC_COMMAND=${CYANEA_HOME}/bin/pactl.sh
	;;
	md )
		EXEC_COMMAND=${CYANEA_HOME}/bin/mdctl.sh
	;;
	sa )
		EXEC_COMMAND=${CYANEA_HOME}/bin/samctl.sh
	;;
	dc )
		EXEC_COMMAND=${CYANEA_HOME}/bin/dcctl.sh
		PROBE_MODE=true
	;;
	* ) 
		usage
	;;
esac


if [ "$PROP_FILE_NAME" = "`basename $PROP_FILE_NAME .properties`" ]
then
	PROP_FILE_NAME=${PROP_FILE_NAME}.properties
fi
	 
# Assume property file is in $CYANEA_HOME/etc, since classpath
# is used for resource.

if [ "${PROBE_MODE}" != "true" ]
then 
	if [  ! -f "${CYANEA_HOME}/etc/${PROP_FILE_NAME}" ]
	then
		usage
	fi
fi

if [ -f ${EXEC_COMMAND} ]
then
	echo ${EXEC_COMMAND} ${COMMAND} ${PROP_FILE_NAME}
	exec ${EXEC_COMMAND} ${COMMAND} ${PROP_FILE_NAME}
else
	echo "Error: Control script ${EXEC_COMMAND} not found."
	exit 1
fi

if [ "$OS" = "Interix" ]; then
	cd $oldDir
fi

